dnl aclocal.m4 - Autoconf macros used at BBL



dnl Report compiler options selected by AC_PROC_CC.
dnl This is mostly for debugging the following macros, by making
dnl it clear who set particular options.  It should be used after
dnl AC_PROG_CC but before other macros to set compiler options.

AC_DEFUN(BBL_MSG_C_OPTIONS,
[AC_MSG_CHECKING(C compiler basic options)
AC_MSG_RESULT($CFLAGS)
])



dnl Choose flags to get additional warnings in the C compiler, and
dnl substitute them for CWARNINGS.  Currently works well only for gcc,
dnl since it must know explicitly what flags to use for which compilers.
dnl The particular flags chosen for gcc are those used within BBLimage
dnl and are chosen to maximize the number of dubious constructs used
dnl without yielding too many false positives; other programmers may 
dnl disagree.
dnl
dnl Adding "-Wpointer-arith" for gcc would be useful for catching some
dnl portability errors, but also causes many spurious warnings for strcpy 
dnl and memset as implemented in RedHat's glibc-2.2.2-10.src.rpm.
dnl
dnl Adding "-ansi" for gcc catches some potential portability problems 
dnl but also generates spurious warnings for the common functions
dnl snprintf, mkstemp, and strdup.  Adding "-pedantic" seems to generate
dnl all sorts of useless warnings and no useful ones.

AC_DEFUN(BBL_C_WARNINGS,
[AC_MSG_CHECKING(C compiler flags for warnings)
if test "$GCC" = "yes"; then
   CWARNINGS="-Wall -Wmissing-prototypes -Wstrict-prototypes"
fi
AC_SUBST(CWARNINGS)
AC_MSG_RESULT($CWARNINGS)
])



dnl Check what flags are needed in the C compiler to create shared
dnl libraries, define SFLAGS to be those additional flags, and
dnl substitute SFLAGS.  Typically, this will be used only in a Makefile.
dnl
dnl Currently deprecated: use BBL_C_PIC and BBL_C_SHARED in new code,
dnl since the flags often need to be used in different places.
dnl
dnl FIXME: Currently works only for gcc.

AC_DEFUN(BBL_C_SHARED_LIBS,
[AC_MSG_CHECKING(C compiler flags for shared libraries)
if test "$GCC" = "yes"; then
   SFLAGS="-fPIC -shared"
fi
AC_MSG_RESULT($SFLAGS)
AC_SUBST(SFLAGS)
])



dnl Check flag(s) to generate position-independent code.
dnl Set PICFLAG to the right value and substitute where needed.
dnl
dnl FIXME: Currently works only for gcc

AC_DEFUN(BBL_C_PIC,
[AC_MSG_CHECKING(C compiler flags for position-independent code)
if test "$GCC" = "yes"; then
   PICFLAG="-fPIC"
fi
AC_MSG_RESULT($PICFLAG)
AC_SUBST(PICFLAG)
])



dnl Check flag(s) to link into a shared library.
dnl Set SHARED to the right value and substitute where needed.
dnl
dnl FIXME: Currently works only for gcc

AC_DEFUN(BBL_C_SHARED,
[AC_MSG_CHECKING(C compiler flags to link a shared library)
if test "$GCC" = "yes"; then
   SHARED="-shared"
fi
AC_MSG_RESULT($SHARED)
AC_SUBST(SHARED)
])



dnl Check if the C compiler supports the restrict keyword, or an equivalent.
dnl If the compiler accepts "restrict", do nothing; if is accepts
dnl "__restrict" or "__restrict__", use that instead; otherwise define
dnl restrict to be empty.

AC_DEFUN(BBL_C_RESTRICT,
[AC_CACHE_CHECK([for restrict], bbl_cv_c_restrict,
[bbl_cv_c_restrict=no
for bbl_kw in restrict __restrict __restrict__ ; do
  AC_TRY_COMPILE(, [int * $bbl_kw p;], [bbl_cv_c_restrict=$bbl_kw; break])
done
])
case "$bbl_cv_c_restrict" in
  restrict | yes) ;;
  no) AC_DEFINE(restrict, ) ;;
  *)  AC_DEFINE_UNQUOTED(restrict, $bbl_cv_c_restrict) ;;
esac
])



dnl BBL_C_INLINE - Check for the inline keyword or equivalent
dnl This macro sets appropriate flags depending on whether or not
dnl the compiler accepts the inline keyword or some equivalent.
dnl The C macro "inline" is undefined if the compiler accepts "inline",
dnl to an equivalent accepted by the compiler, or to blank.  The C
dnl macro HAVE_INLINE is defined as 1 if the compiler accepts inline
dnl or some equivalent, and undefined otherwise.  The C macro inlineable
dnl is set to "static inline" if the compiler accepts inline or some
dnl equivalent, and to "extern" otherwise.

AC_DEFUN(BBL_C_INLINE,
[AC_CACHE_CHECK([for working inline], bbl_c_inline,
[bbl_c_inline=no
for kw in inline __inline__ __inline; do
  AC_TRY_COMPILE(, [} static $kw foo() {], [bbl_c_inline=$kw; break])
done
])
case "$bbl_c_inline" in
  inline | yes) 
    AC_DEFINE(HAVE_INLINE, 1)
    AC_DEFINE(inlineable, static inline)
    ;;
  no) 
    AC_DEFINE(inline, )
    AC_DEFINE(inlineable, extern)
    ;;
  *)
    AC_DEFINE_UNQUOTED(inline, $bbl_c_inline)
    AC_DEFINE(HAVE_INLINE, 1)
    AC_DEFINE(inlineable, static inline)
    ;;
esac
])
