/****************************************************************************
clap.c - C wrapper functions for the LAPACK library

Author:  Paul Hughett

Copyright (c) 2000-2001 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This header file declares the C wrapper functions for the LAPACK
Fortran subroutines used by the Voxel Kit.
****************************************************************************/

#ifndef CLAP_H
#define CLAP_H


#ifdef __cplusplus          /* Allow to be called from C++ */
extern "C" {
#endif


/*--------------------------------------------------------------------------
C typedefs for Fortran types

NOTE that these will often need to be modified for each platform
--------------------------------------------------------------------------*/

typedef char   fchar1;     /* Fortran character*1 */
typedef long   fint;       /* Fortran integer */
typedef float  freal;      /* Fortran real */
typedef double fdouble;    /* Fortran double precision */



/*------------------------------------------------------------------------
Prototypes for BLAS subroutines
-------------------------------------------------------------------------*/

extern void dgemm_(fchar1 *transa, fchar1 *transb, fint *m, fint *n, fint *k,
    fdouble *alpha, fdouble *a, fint *lda, fdouble *b, fint *ldb,
    fdouble *beta, fdouble *c, fint *ldc);
extern void sgemm_(fchar1 *transa, fchar1 *transb, fint *m, fint *n, fint *k,
    freal *alpha, freal *a, fint *lda, freal *b, fint *ldb,
    freal *beta, freal *c, fint *ldc);


/*-------------------------------------------------------------------------
Prototypes for LAPACK subroutines
-------------------------------------------------------------------------*/

extern void dgetrf_(fint *m, fint *n, fdouble *a, fint *lda, fint *ipiv,
    fint *info);
extern void sgetrf_(fint *m, fint *n, freal   *a, fint *lda, fint *ipiv,
    fint *info);

extern void dgetri_(fint *n, fdouble *a, fint *lda, fint *ipiv,
    fdouble *work, fint *lwork, fint *info);
extern void sgetri_(fint *n, freal *a, fint *lda, fint *ipiv,
    freal *work, fint *lwork, fint *info);
extern void dgetrs_(fchar1 *trans, fint *n, fint *nrhs, fdouble *a, fint *lda,
    fint *ipiv, fdouble *b, fint *ldb, fint *info);
extern void sgetrs_(fchar1 *trans, fint *n, fint *nrhs, freal *a, fint *lda,
    fint *ipiv, freal *b, fint *ldb, fint *info);
extern void dsyev_(fchar1 *jobz, fchar1 *uplo, fint *n, fdouble *a,
    fint *lda, fdouble *w, fdouble *work, fint *lwork, fint *info);
extern void ssyev_(fchar1 *jobz, fchar1 *uplo, fint *n, freal *a,
    fint *lda, freal *w, freal *work, fint *lwork, fint *info);


/*------------------------------------------------------------------------
BLAS wrapper functions
-------------------------------------------------------------------------*/

extern int clap_dgemm(int transa, int transb, int m, int n, int k,
    double alpha, double *a, int lda, double *b, int ldb,
    double beta, double *c, int ldc);
extern int clap_sgemm(int transa, int transb, int m, int n, int k,
    float alpha, float *a, int lda, float *b, int ldb,
    float beta, float *c, int ldc);


/*--------------------------------------------------------------------------
LAPACK wrapper functions
---------------------------------------------------------------------------*/

extern int clap_dsyev(int both, int up, int n, double *a, int lda, double *w);
extern int clap_ssyev(int both, int up, int n, float  *a, int lda, float  *w);

#ifdef __cplusplus
}
#endif

#endif  /* CLAP_H */
