/****************************************************************************
dstring.h - Prototypes for functions to process dynamic strings

Author:  Paul Hughett

Copyright (c) 1998 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This public header file contains prototypes for various functions to
process dynamically allocated strings (but probably useful elsewhere
as well).  These functions were originally intended for bblimage but
have not yet actually been used or tested; the particular need turned
out to be easier to satisfy with in-line code.

****************************************************************************/


#ifndef DSTRING_H
#define DSTRING_H

#include <stddef.h>

#ifdef __cplusplus          /* Allow to be called from C++ */
extern "C" {
#endif

/*---------------------------------------------------------------------------
dstring - Dynamically allocated string type
---------------------------------------------------------------------------*/

struct dynamic_string {
    size_t alloc;      /* Number of bytes allocated, or zero */
    char *string;      /* Pointer to the null-terminated string itself */
};

typedef struct dynamic_string dstring;


/*-------------------------------------------------------------------------- 
Functions for handling dynamic strings 
---------------------------------------------------------------------------*/

extern dstring *dstrcreate(void);
extern void dstrdestroy(dstring *s);
extern void dstralloc(dstring *s, size_t n);
extern char *dstrextract(dstring *s);
extern dstring *dstrcat(dstring *dest, const dstring *src);
extern void augment_string_array(char **array[], size_t *nstring, 
    size_t *nalloc, char *string);

#ifdef __cplusplus
}
#endif

#endif /* DSTRING_H */
