/****************************************************************************
errm.h - Prototypes for error management functions

Author:  Paul Hughett

Copyright (c) 1998-2000 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This public header file contains prototypes for various error management
functions used within bblimage (but probably useful elsewhere as well).
The functions themselves are currently defined in image_io.c, but may be
pulled out into a separate file someday soon.

FIXME:  Almost no one actually uses these error codes.  Help them see the
error of their ways.

FIXME: Add a global variable like errno to record the error state for
any library that uses errm?  (But note that multi-threading is rather
incompatible with a global error flag.)  Add function to translate the
error code into a readable string?  Allow the function reporting the
error to include a descriptive string that can be used for debugging?
****************************************************************************/


#ifndef ERRM_H
#define ERRM_H

#ifdef __cplusplus          /* Allow to be called from C++ */
extern "C" {
#endif

/* Generic error codes */
#define ERR_OKAY      0      /* No error, operation successful */
#define ERR_UNIMP     1      /* Not yet implemented */
#define ERR_ILLOP     2      /* Illegal operation */
#define ERR_INCOMP    3      /* Incompatible operands */
#define ERR_MALLOC    4      /* Unable to allocate sufficient memory */
#define ERR_EOF       5      /* Unexpected end of file */
#define ERR_INIT      6      /* Uninitialized or invalid operand */
#define ERR_DOMAIN    7      /* Operand not valid */
#define ERR_RANGE     8      /* Result is not representable */
#define ERR_FILE      9      /* Input/output error */


/* Public global variables */
extern int errm_abort_flag;       /* Abort (and core dump) on error? */

/* Public functions */
extern void warning(const char *message, ...);
extern void fatal  (const char *message, ...);
extern void panic  (const char *message, ...);

extern void err_msg (const char *message );  /* Deprecated */

#ifdef __cplusplus
}
#endif

#endif /* ERRM_H */
