/****************************************************************************
vxli.h - Private header file for the Voxel Kit

Author:  Paul Hughett

Copyright (c) 1998-2000 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This file defines private structures and prototypes for the Voxel Kit.
If the compiler supports inlining, then it also includes the definitions
of the inlineable internal functions.

FIXME:  Check that all the public and private functions are correctly
classified.

FIXME: Think through which of these functions should be inlineable and
which need to be callable, and change the code to match.
*****************************************************************************/


#ifndef VXLI_H
#define VXLI_H



/*-------------------------------------------------------------------------
Force prerequisite header files to be loaded
--------------------------------------------------------------------------*/

#ifndef CONFIG_H
#include "config.h"
#endif

#ifndef VOXEL_H
#include "voxel.h"
#endif



#ifdef __cplusplus          /* Allow to be called from C++ */
extern "C" {
#endif


/*-------------------------------------------------------------------------
Callable functions
--------------------------------------------------------------------------*/

extern long vxli_count(voxel_array *src);
extern long vxli_delta(voxel_array *src, long *coords);
extern long vxli_offset(voxel_array *src, long *coords, int errifout);
extern long vxli_offset2(long rank, long *dimen, long *coords, int errifout);
extern unsigned char *vxli_locate(voxel_array *src, long *coords,
    int errifout);
extern long vxli_step(voxel_array *src, int dim);
extern long vxli_step2(long rank, long *dimen, int dim);
extern int  vxli_same_shape(voxel_array *src1, voxel_array *src2);



/*-------------------------------------------------------------------------
Inlineable functions
--------------------------------------------------------------------------*/

inlineable long vxli_offset_nocheck(voxel_array *src, long*coords);
inlineable void vxli_firstvoxel(int rank, long *coord);
inlineable int  vxli_nextvoxel (int rank, long *dimen, long *coord);
inlineable void vxli_firstrow  (int rank, long *coord);
inlineable int  vxli_nextrow   (int rank, long *dimen, long *coord);
inlineable void vxli_lastrow   (int rank, long *dimen, long *coord);
inlineable int  vxli_prevrow   (int rank, long *dimen, long *coord);
inlineable void vxli_firstrow2 (int rank, long *coord);
inlineable int  vxli_nextrow2  (int rank, long *dimen, int idim, long *coord);



/*-------------------------------------------------------------------------
Definitions of inlineable functions if compiler supports inline
--------------------------------------------------------------------------*/

#ifdef HAVE_INLINE
#include "vxli2.c"
#endif


#ifdef __cplusplus
}
#endif

#endif  /* VXLI_H */
