/****************************************************************************
bblanz.c - BBL's version of the Analyze View header file

Author:  Paul Hughett

Copyright (c) 2000 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This source file contains a function to import/export/dump BBL's
version of the Analyze View header file, which was apparently derived
from the Analyze View header created by Mayo Foundation via the
analyze_hdr.h header file defined in NRIA.  However, the precise
relationship has not yet been established.  See the bblanz.h header
file for more details.

FIXME: bblanz is more or less a BBL-specific perversion of the AnalyzeView
header and should be moved into a BBL-specific package.
*****************************************************************************/

static const char rcsid[] =
"$Id: bblanz.c,v 1.4 2002/02/05 15:54:29 hughett Exp $ Release $Name:  $";


#include "bblanz.h"
#include "errm.h"



/*---------------------------------------------------------------------
bblanz - Import, export, or dump a header file in BBL Analyze format

FIXME: Some fields should probably be unsigned, or printed as hex
values.

FIXME: The use of LONG below might be problematic, but INT will fail on
machines for which int is only 16 bits.
----------------------------------------------------------------------*/

struct dsr *
bblanz(
    struct exim_mode *mode,         /* Import, export, or dump? */
    struct dsr *dsr)                /* Struct to act on */
{
    int err;

    /* Allocate space for the entire struct */
    dsr = exim_alloc (mode, dsr, sizeof(struct dsr), INTP_UCHAR);

    /* Process the header_key substructure */
    SCALAR(     hk.sizeof_hdr,    LONG,   INT4,   "sizeof_hdr:    %d\n");
    VECTOR( 10, hk.data_type,     UCHAR,  UCHAR,  "data_type:     [%#x ]\n");
    VECTOR( 18, hk.db_name,       UCHAR,  UCHAR,  "db_name:       [%#x ]\n");
    SCALAR(     hk.extents,       LONG,   INT4,   "extents:       %d\n");
    SCALAR(     hk.session_error, SHORT,  INT2,   "session_error: %d\n");
    SCALAR(     hk.regular,       UCHAR,  UCHAR,  "regular:       %#x\n");
    SCALAR(     hk.hkey_un0,      UCHAR,  UCHAR,  "hkey_un0:      %#x\n");

    /* Process the image_dimension substructure */
    VECTOR(  8, dime.dim,         SHORT,  INT2,   "dim:           [%d ]\n");
    VECTOR(  4, dime.vox_units,   UCHAR,  UCHAR,  "vox_units:     [%#x ]\n");
    VECTOR(  8, dime.cal_units,   UCHAR,  UCHAR,  "cal_units:     [%#x ]\n");
    SCALAR(     dime.unused1,     SHORT,  INT2,   "unused1:       %d\n");
    SCALAR(     dime.datatype,    SHORT,  INT2,   "datatype:      %#x\n");
    SCALAR(     dime.bitpix,      SHORT,  INT2,   "bitpix:        %d\n");
    SCALAR(     dime.dim_un0,     SHORT,  INT2,   "dim_un0:       %d\n");
    VECTOR(  8, dime.pixdim,      FLOAT,  FLOAT4, "pixdim:        [%f ]\n");
    SCALAR(     dime.vox_offset,  FLOAT,  FLOAT4, "vox_offset:    %f\n");
    SCALAR(     dime.funused1,    FLOAT,  FLOAT4, "funused1:      %f\n");
    SCALAR(     dime.funused2,    FLOAT,  FLOAT4, "funused2:      %f\n");
    SCALAR(     dime.funused3,    FLOAT,  FLOAT4, "funused3:      %f\n");
    SCALAR(     dime.cal_max,     FLOAT,  FLOAT4, "cal_max:       %f\n");
    SCALAR(     dime.cal_min,     FLOAT,  FLOAT4, "cal_min:       %f\n");
    SCALAR(     dime.compressed,  LONG,   INT4,   "compressed:    %#x\n");
    SCALAR(     dime.verified,    LONG,   INT4,   "verified:      %#x\n");
    SCALAR(     dime.glmax,       LONG,   INT4,   "glmax:         %d\n");
    SCALAR(     dime.glmin,       LONG,   INT4,   "glmin:         %d\n");

    /* Process the data_history substructure */
    VECTOR( 80, hist.descrip,     UCHAR,  UCHAR,  "descrip:       [%#x ]\n");
    VECTOR( 24, hist.aux_file,    UCHAR,  UCHAR,  "aux_file:      [%#x ]\n");
    SCALAR(     hist.orient,      UCHAR,  UCHAR,  "orient:        %#x\n");
    VECTOR( 10, hist.originator,  UCHAR,  UCHAR,  "originator:    [%#x ]\n");
    VECTOR( 10, hist.generated,   UCHAR,  UCHAR,  "generated:     [%c]\n");
    VECTOR( 10, hist.scannum,     UCHAR,  UCHAR,  "scannum:       [%c]\n");
    VECTOR( 10, hist.patient_id,  UCHAR,  UCHAR,  "patient_id:    [%c]\n");
    VECTOR( 10, hist.exp_date,    UCHAR,  UCHAR,  "exp_date:      [%#x ]\n");
    VECTOR( 10, hist.exp_time,    UCHAR,  UCHAR,  "exp_time:      [%#x ]\n");
    VECTOR(  3, hist.hist_un0,    UCHAR,  UCHAR,  "hist_un0:      [%#x ]\n");
    SCALAR(     hist.views,       LONG,   INT4,   "views:         %d\n");
    SCALAR(     hist.vols_added,  LONG,   INT4,   "vols_added:    %d\n");
    SCALAR(     hist.start_field, LONG,   INT4,   "start_field:   %#x\n");
    SCALAR(     hist.field_skip,  LONG,   INT4,   "field_skip:    %#x\n");
    SCALAR(     hist.omax,        LONG,   INT4,   "omax:          %d\n");
    SCALAR(     hist.omin,        LONG,   INT4,   "omin:          %d\n");
    SCALAR(     hist.smax,        LONG,   INT4,   "smax:          %d\n");
    SCALAR(     hist.smin,        LONG,   INT4,   "smin:          %d\n");

    return dsr;
}
