/**************************************************************************
decomment.c - Remove comments from a commented data file

Author:  Paul Hughett

Copyright (c) 1999 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This program removes the comments and blank lines from, and pastes
together the continuation lines of a commented data file, preparing
the file for SAS or another program that does not understand commented
data.  It takes its input from the file named on the command line, or
from standard input, and writes its output to standard output.

**************************************************************************/

static const char rcsid[] = "$Id: decomment.c,v 1.3 1999/01/23 21:05:42 hughett Exp $ Release $Name:  $";

#include <stdio.h>
#include <stdlib.h>

#include "cdata.h"
#include "errm.h"
#include "memm.h"


int
main(int argc, char *argv[])
{
    FILE *input = stdin;      /* File to read, or standard input */
    int ndat;                 /* Number of data on current input line */
    char **dat;               /* Array of data fields */
    char **cmt;               /* Array of comment fields */
    int line;                 /* Line number in the input file */

    /* Open the input file; if none, use standard input */
    if (argc >= 2) {
	input = fopen(argv[1], "r");
	if (input == 0)
	    fatal("Unable to open input file %s", argv[1]);
    }

    /* Read each line, and write back out sans comments and other goodies */
    for (line = 1; !feof(input); line++) {
	ndat = cdata_read(input, &dat, &cmt);
	if (ferror(input))
	    fatal("Error reading input file %s", argv[1]);
	if (ndat > 0)
	    cdata_decomment(stdout, ndat, dat, cmt);
	cdata_free(ndat, dat, cmt);
    }

    exit(EXIT_SUCCESS);
}
