/****************************************************************************
dumpbblanz - Dump a BBL Analyze header file

Author:  Paul Hughett

Copyright (c) 2000 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This program reads the BBL Analyze header file named on the command line
and dumps it to standard output in a (more or less) human-readable.
Everything is dumped, even the fields which are allegely unused.

FIXME: bblanz is more or less a BBL-specific perversion of the AnalyzeView
header and should be moved into a BBL-specific package.
*****************************************************************************/

static const char rcsid[] =
"$Id: dumpbblanz.c,v 1.2 2002/02/05 15:54:29 hughett Exp $ Release $Name:  $";

#include <stdio.h>

#include "bblanz.h"
#include "errm.h"
#include "exim.h"


int main(int argc, char *argv[])
{
    FILE *input;                  /* Header file to be dumped */
    struct exim_mode *mode;       /* Field-independent parameters */
    int bigend = 1;               /* Always read as big endian */
    struct dsr *dsr = 0;          /* Placeholder for header struct */

    /* Open the input file */
    if (argc < 2)
        fatal("The header file must be specified");
    input = fopen(argv[1], "r");
    if (input == 0)
        fatal("Unable to open the input file");

    /* Configure to dump the file */
    mode = exim_create_mode(EXIM_IMDUMP, input, stdout, bigend);
    if (mode == 0)
        fatal("Insufficient memory to create mode");

    /* Dump the input file */
    dsr = bblanz(mode, dsr);

    /* Clean up and exit */
    exim_destroy_mode(mode);
    fclose(input);
    return 0;
}
