/****************************************************************************
rowcol.c - Generate the "row/column" test image

Author:  Paul Hughett

Copyright (c) 2000 Trustees of the University of Pennsylvania
See the file COPYING for license terms.

This program generates a simple "row/column" image whose primary purpose
is for testing functions and programs that import external image data from
a file.  The test image, in its native form, is 2 slices by 256 rows by
256 columns by 2 echoes of unsigned char data.  In the first slice, the
first echo is the row number and the second echo is the column number; in
the second slice, the two echoes are reversed.  This image also produces
a simple internal image if read as 2-byte unsigned ints, either big or
little endian; figuring out what it is is left as an exercise for the
reader.  The test image is always output to the file "rowcol.img".
*****************************************************************************/

static const char rcsid[] = "$Id: rowcol.c,v 1.1 2000/01/26 16:25:16 hughett Exp $ Release $Name:  $";

#include <stdio.h>

#include "errm.h"


int main(int argv, char *argc[])
{
    char *fname = "rowcol.img";   /* Name of the output file */
    FILE *file;                   /* Output stream */
    unsigned char buff[2*256];    /* Scanline buffer */
    int r, c;                     /* Row and column indices */
    int n;

    /* Open the output file */
    file = fopen(fname, "wb");
    if (file == 0)
	fatal("Unable to open output file");

    /* Write the first slice */
    for (r = 0; r < 256; r++) {
	for (c = 0; c < 256; c++) {
	    buff[2*c]   = r;
	    buff[2*c+1] = c;
	}
	n = fwrite(buff, 1, 512, file);
	if (n < 512)
	    fatal("Error writing to output file");
    }

    /* Write the second slice */
    for (r = 0; r < 256; r++) {
	for (c = 0; c < 256; c++) {
	    buff[2*c]   = c;
	    buff[2*c+1] = r;
	}
	n = fwrite(buff, 1, 512, file);
	if (n < 512)
	    fatal("Error writing to output file");
    }

    fclose(file);
    return 0;
}

