/***************************************************************************
test_clap.c - Test the C-wrapped LAPACK functions

****************************************************************************/

#include <stdio.h>

#include "clap.h"

/* Prototypes */
int test_dsyev();
void test_xerbla();


int main(
    int argc,
    char *argv[])
{
    int any = 0;           /* Any errors found? */
    int err = 0;           /* Error in current test? */

    test_xerbla();

    err = test_dsyev();
    if (err) any = err;

    return any;

}


/* Testing clap_dsyev() */
int
test_dsyev()
{
    double a[9] = {1.0, 2.0, 3.0,      /* Array to solve; eigenvectors */
                   2.0, 4.0, 5.0,
                   3.0, 5.0, 6.0};
    double w[3];                       /* Eigenvalues */
    int row, col;                      /* Loop over matrix elements */
    int info = 0;                      /* Status value returned */

    /* Show the system to be solved */
    printf("Solving a real symmetric eigensystem:\n");
    for (row = 0; row < 3; row++) {
	for (col = 0; col < 3; col++) {
	    printf("   %10f", a[3*row+col]);
	}
	printf("\n");
    }

    /* Solve it */
    info = clap_dsyev(1, 1, 3, a, 3, w);

    /* Show the solution */
    printf("Info value is %d\n", info);
    printf("Eigenvalues are: %10f, %10f, %10f\n", w[0], w[1], w[2]);
    printf("Eigenvectors are:\n");
    for (row = 0; row < 3; row++) {
	for (col = 0; col < 3; col++) {
	    printf("   %10f", a[3*row+col]);
	}
	printf("\n");
    }

    return info;
}


void test_xerbla()
{
    xerbla_(NULL, -3);
    return;
}

